@@ -21,8 +21,6 @@
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ****************************************************************************/
 
-#include <Python.h>
-#include "imagelabel.h"
 #include <qpixmap.h>
 #include <qtimer.h>
 #include <qtooltip.h>
@@ -31,16 +29,18 @@
 #include <kimageeffect.h>
 #include <ktempfile.h>
 #include <kio/job.h>
+#include "karambaapp.h"
+#include "imagelabel.h"
 
 // Effect
 Effect::Effect(ImageLabel* img, int msec) :
-	myImage(img)
+  myImage(img)
 {
-	if (msec > 0)
-	{
-		// remove the effect after the given time
-		//QTimer::singleShot (millisec, myImage, SLOT(slotEffectExpired()));
-		//timer -> changeInterval(millisec);
+  if (msec > 0)
+  {
+    // remove the effect after the given time
+    //QTimer::singleShot (millisec, myImage, SLOT(slotEffectExpired()));
+    //timer -> changeInterval(millisec);
     millisec = msec;
   }
   else
@@ -66,14 +66,14 @@ void Effect::startTimer()
 Intensity::Intensity(ImageLabel* img, float r, int millisec) :
   Effect(img, millisec)
 {
-	ratio = r;
-	ratio = (ratio > 1)  ? 1 : ratio;
-	ratio = (ratio < -1) ? -1 : ratio;
+  ratio = r;
+  ratio = (ratio > 1)  ? 1 : ratio;
+  ratio = (ratio < -1) ? -1 : ratio;
 }
 
 KPixmap Intensity::apply(KPixmap pixmap)
 {
-	return KPixmapEffect::intensity(pixmap, ratio);
+  return KPixmapEffect::intensity(pixmap, ratio);
 }
 
 // ChannelIntensity
@@ -81,23 +81,23 @@ ChannelIntensity::ChannelIntensity(ImageLabel* img, float r, QString c,
                                    int millisec) :
   Effect(img, millisec)
 {
-	ratio = r;
-	ratio = (ratio > 1)  ? 1 : ratio;
-	ratio = (ratio < -1) ? -1 : ratio;
+  ratio = r;
+  ratio = (ratio > 1)  ? 1 : ratio;
+  ratio = (ratio < -1) ? -1 : ratio;
 
-	channel = 0;
-	if (c.find("red", 0 , false))
-	{
-		channel = 0;
-	}
-	else if (c.find("green", 0, false))
-	{
-		channel = 1;
-	}
-	else if (c.find("blue", 0, false))
-	{
-		channel = 2;
-	}
+  channel = 0;
+  if (c.find("red", 0 , false))
+  {
+    channel = 0;
+  }
+  else if (c.find("green", 0, false))
+  {
+    channel = 1;
+  }
+  else if (c.find("blue", 0, false))
+  {
+    channel = 2;
+  }
 }
 
 KPixmap ChannelIntensity::apply(KPixmap pixmap)
@@ -406,104 +406,112 @@ bool ImageLabel::click(QMouseEvent* e)
 void ImageLabel::parseImages(QString fn, QString fn_roll, int _xoff,
                              int _yoff, int _xon, int _yon)
 {
-	//fn = filename;
-	//fn_roll = filename_roll;
+  //fn = filename;
+  //fn_roll = filename_roll;
 
-	xoff = _xoff;
-	yoff = _yoff;
-	xon = _xon;
-	yon = _yon;
+  xoff = _xoff;
+  yoff = _yoff;
+  xon = _xon;
+  yon = _yon;
 
-	// use the first line
-	QStringList sList = QStringList::split( "\n", fn );
-	QString fileName = *sList.begin();
-	QFileInfo fileInfo( fileName );
-	QString path;
+  // use the first line
+  QStringList sList = QStringList::split( "\n", fn );
+  QString fileName = *sList.begin();
+  QFileInfo fileInfo( fileName );
+  QString path;
 
-	QRegExp rx("^http://",false);
-	bool fileOnNet = (rx.search(fileName)!=-1)?true:false;
+  QRegExp rx("^http://",false);
+  bool fileOnNet = (rx.search(fileName)!=-1)?true:false;
 
 
-	if( fileInfo.isRelative() && !fileOnNet )
-	{
-	 path = themePath + "/" + fileName;
-	}
-	else
-	{
-	 path = fileName;
-	}
+  if( fileInfo.isRelative() && !fileOnNet )
+  {
+   path = themePath + "/" + fileName;
+  }
+  else
+  {
+   path = fileName;
+  }
 
-	if ( fileOnNet )
-	{
-	  QString tmpFile;
-	  if(KIO::NetAccess::download(KURL(path), tmpFile))
-	  {
-		  pixmap_off = KPixmap(tmpFile);
-		  KIO::NetAccess::removeTempFile(tmpFile);
-		   qDebug( "Downloaded: " + path + " to " + tmpFile );
-	  }
-	  else
-	  {
-		  qDebug( "Error Downloading: " + path );
-	  }
-	}
-	else
-	{
-		pixmap_off = KPixmap( path );
-	}
+  if ( fileOnNet )
+  {
+    QString tmpFile;
+#if defined(KDE_3_2)
+    if(KIO::NetAccess::download(KURL(path), tmpFile, karambaApp->parentWindow()))
+#else
+    if(KIO::NetAccess::download(KURL(path), tmpFile))
+#endif
+    {
+      pixmap_off = KPixmap(tmpFile);
+      KIO::NetAccess::removeTempFile(tmpFile);
+      qDebug( "Downloaded: %s to %s", path.ascii(), tmpFile.ascii() );
+    }
+    else
+    {
+      qDebug( "Error Downloading: %s", path.ascii());
+    }
+  }
+  else
+  {
+    pixmap_off = KPixmap( path );
+  }
 
-	pixmapOffWidth = pixmap.width();
-	pixmapOffHeight = pixmap.height();
+  pixmapOffWidth = pixmap.width();
+  pixmapOffHeight = pixmap.height();
 
-	rect_off = QRect(xoff,yoff,pixmapWidth,pixmapHeight);
+  rect_off = QRect(xoff,yoff,pixmapWidth,pixmapHeight);
 /////////////////////////////
-	if (fn_roll.isEmpty())
-		return;
+  if (fn_roll.isEmpty())
+    return;
 
-	rollover=true;
-	sList = QStringList::split( "\n", fn_roll );
-	fileName = *sList.begin();
-	fileInfo = QFileInfo( fileName );
+  rollover=true;
+  sList = QStringList::split( "\n", fn_roll );
+  fileName = *sList.begin();
+  fileInfo = QFileInfo( fileName );
 
-	fileOnNet = (rx.search(fileName)!=-1)?true:false;
+  fileOnNet = (rx.search(fileName)!=-1)?true:false;
 
 
-	if( fileInfo.isRelative() && !fileOnNet )
-	{
-	 path = themePath + "/" + fileName;
-	}
-	else
-	{
-	 path = fileName;
-	}
+  if( fileInfo.isRelative() && !fileOnNet )
+  {
+   path = themePath + "/" + fileName;
+  }
+  else
+  {
+   path = fileName;
+  }
 
-	if ( fileOnNet )
-	{
-	  QString tmpFile;
-	  if(KIO::NetAccess::download(KURL(path), tmpFile))
-	  {
-		  pixmap_on = KPixmap(tmpFile);
-		  KIO::NetAccess::removeTempFile(tmpFile);
-		   qDebug( "Downloaded: " + path + " to " + tmpFile );
-	  }
-	  else
-	  {
-		  qDebug( "Error Downloading: " + path );
-	  }
-	}
-	else
-	{
-		pixmap_on = KPixmap( path );
-	}
-	pixmapOnWidth = pixmap_on.width();
-	pixmapOnHeight = pixmap_on.height();
+  if ( fileOnNet )
+  {
+    QString tmpFile;
+#if defined(KDE_3_2)
+    if(KIO::NetAccess::download(KURL(path), tmpFile, karambaApp->parentWindow()))
+#else
+    if(KIO::NetAccess::download(KURL(path), tmpFile))
+#endif
+    {
+      pixmap_on = KPixmap(tmpFile);
+      KIO::NetAccess::removeTempFile(tmpFile);
+      qDebug( "Downloaded: %s to %s", path.ascii(), tmpFile.ascii());
+    }
+    else
+    {
+      qDebug( "Error Downloading: %s", path.ascii());
+    }
+  }
+  else
+  {
+    pixmap_on = KPixmap( path );
+  }
+  pixmapOnWidth = pixmap_on.width();
+  pixmapOnHeight = pixmap_on.height();
 
-	rect_on = QRect(xon,yon,pixmapOnWidth,pixmapOnHeight);
+  rect_on = QRect(xon,yon,pixmapOnWidth,pixmapOnHeight);
 }
 
 void ImageLabel::setKaramba(karamba* k)
 {
-	myKaramba = k;
+  myKaramba = k;
 }
 
 void ImageLabel::setBackground(int b)
@@ -513,98 +521,98 @@ void ImageLabel::setBackground(int b)
 
 void ImageLabel::rolloverImage(QMouseEvent *e)
 {
-	if (!rollover)
-		return;
+  if (!rollover)
+    return;
 
-	if (zoomed)
-	{
-		if (!rect_off.contains(e->pos()))
-		{
-			// rollover the image to the zoomed image
-			//setValue(fn_roll);
-			setX(xoff);
-			setY(yoff);
-			pixmap = pixmap_off;
-			pixmapWidth = pixmapOffWidth;
-			pixmapHeight = pixmapOffHeight;
-			zoomed = false;
-			myKaramba->step();
-		}
-	}
-	else
-	{
-		if (rect_off.contains(e->pos()))
-		{
-			// rollover the image to the zoomed image
-			//setValue(fn_roll);
-			setX(xon);
-			setY(yon);
-			pixmap = pixmap_on;
-			pixmapWidth = pixmapOnWidth;
-			pixmapHeight = pixmapOnHeight;
-			zoomed = true;
-			myKaramba->step();
-		}
-	}
+  if (zoomed)
+  {
+    if (!rect_off.contains(e->pos()))
+    {
+      // rollover the image to the zoomed image
+      //setValue(fn_roll);
+      setX(xoff);
+      setY(yoff);
+      pixmap = pixmap_off;
+      pixmapWidth = pixmapOffWidth;
+      pixmapHeight = pixmapOffHeight;
+      zoomed = false;
+      myKaramba->step();
+    }
+  }
+  else
+  {
+    if (rect_off.contains(e->pos()))
+    {
+      // rollover the image to the zoomed image
+      //setValue(fn_roll);
+      setX(xon);
+      setY(yon);
+      pixmap = pixmap_on;
+      pixmapWidth = pixmapOnWidth;
+      pixmapHeight = pixmapOnHeight;
+      zoomed = true;
+      myKaramba->step();
+    }
+  }
 }
 
 void ImageLabel::setTooltip(QString txt)
 {
-	QRect rect(getX(),getY(),pixmapWidth,pixmapHeight);
-	QToolTip::add(myKaramba, rect, txt);
+  QRect rect(getX(),getY(),pixmapWidth,pixmapHeight);
+  QToolTip::add(myKaramba, rect, txt);
 }
 
 
 void ImageLabel::removeEffects()
 {
-	if (imageEffect != 0)
-	{
-		delete imageEffect;
-		imageEffect = 0;
-	}
+  if (imageEffect != 0)
+  {
+    delete imageEffect;
+    imageEffect = 0;
+  }
   applyTransformations();
 }
 
 void ImageLabel::intensity(float ratio, int millisec)
 {
-	if (imageEffect != 0)
-	{
-		delete imageEffect;
-		imageEffect = 0;
-	}
-	//KPixmapEffect::intensity(pixmap, ratio);
-	imageEffect = new Intensity(this, ratio, millisec);
+  if (imageEffect != 0)
+  {
+    delete imageEffect;
+    imageEffect = 0;
+  }
+  //KPixmapEffect::intensity(pixmap, ratio);
+  imageEffect = new Intensity(this, ratio, millisec);
   applyTransformations();
 }
 
 void ImageLabel::channelIntensity(float ratio, QString channel, int millisec)
 {
-	if (imageEffect != 0)
-	{
-		delete imageEffect;
-		imageEffect = 0;
-	}
-	//KPixmapEffect::channelIntensity(pixmap, ratio, rgbChannel);
-	imageEffect = new ChannelIntensity(this, ratio, channel, millisec);
+  if (imageEffect != 0)
+  {
+    delete imageEffect;
+    imageEffect = 0;
+  }
+  //KPixmapEffect::channelIntensity(pixmap, ratio, rgbChannel);
+  imageEffect = new ChannelIntensity(this, ratio, channel, millisec);
   applyTransformations();
 }
 
 void ImageLabel::toGray(int millisec)
 {
-	if (imageEffect != 0)
-	{
-		delete imageEffect;
-		imageEffect = 0;
-	}
-	//KPixmapEffect::toGray(pixmap);
-	imageEffect = new ToGray(this, millisec);
-	applyTransformations();
+  if (imageEffect != 0)
+  {
+    delete imageEffect;
+    imageEffect = 0;
+  }
+  //KPixmapEffect::toGray(pixmap);
+  imageEffect = new ToGray(this, millisec);
+  applyTransformations();
 }
 
 void ImageLabel::slotEffectExpired()
 {
-	removeEffects();
-	myKaramba -> externalStep();
+  removeEffects();
+  myKaramba -> externalStep();
 }
 
 void ImageLabel::attachClickArea(QString leftMouseButton,
