@@ -354,14 +354,8 @@ bool karamba::parseConfig()
         toggleLocked->setChecked( getBoolean( "LOCKED", line ) );
         slotToggleLocked();
 
-
-        getInt( "X",line );
-        getInt( "Y",line );
-
         x = ( x < 0 ) ? 0:x;
         y = ( y < 0 ) ? 0:y;
-        move(x,y);
-
 
         if( w == 0 ||  h == 0)
         {
@@ -392,6 +386,7 @@ bool karamba::parseConfig()
             y = 0;
           }
 
+        move(x,y);
         pm = QPixmap(size());
 
         if( getBoolean("ONTOP", line ) )
@@ -423,7 +418,7 @@ bool karamba::parseConfig()
 
 
         bool dfound=false;
-        int desktop = getInt("DESKTOP", line, dfound);
+        //int desktop = getInt("DESKTOP", line, dfound);
         if (dfound)
         {
           info->setDesktop( dfound );
@@ -462,13 +457,12 @@ bool karamba::parseConfig()
         }
         if( getBoolean("LEFTBAR", line) )
         {
-          int dw = QApplication::desktop()->width();
+          //int dw = QApplication::desktop()->width();
           move( 0, y );
           KWin::setStrut( winId(), w, 0, 0, 0 );
           toggleLocked->setChecked( true );
           slotToggleLocked();
           toggleLocked->setEnabled(false);
-
         }
 
         bool found = false;
@@ -798,7 +792,7 @@ void karamba::startNewKaramba()
   }
 }
 
-void karamba::popupNotify(int item)
+void karamba::popupNotify(int)
 {
   //qDebug("karamba::popupNotify");
 }
@@ -1045,16 +1039,22 @@ void karamba::setSensor(QString &line, Meter* meter)
       int interval = getInt("INTERVAL",line);
       interval = (interval == 0)?5000:interval;
       sensor = ( sensorMap["DISK"] = new DiskSensor( interval ) );
-          connect( sensor, SIGNAL(initComplete()),
-            this,SLOT(externalStep()));
+      connect( sensor, SIGNAL(initComplete()), this, SLOT(externalStep()) );
       sensorList->append( sensor );
     }
     // meter->setMax( ((DiskSensor*)sensor)->getTotalSpace(mntPt)/1024 );
     SensorParams *sp = new SensorParams(meter);
     QString mntPt = getString("MOUNTPOINT",line);
     if( mntPt == ""  )
-      mntPt = "/";
-
+    {
+        mntPt = "/";
+    }
+    // remove any trailing '/' from mount points in the .theme config, our
+    // mntMap doesn't like trailing '/'s for matching in DiskSensor
+    if( mntPt.length() > 1 && mntPt.endsWith("/") )
+    {
+        mntPt.remove( mntPt.length()-1, 1 );
+    }
     sp->addParam("MOUNTPOINT",mntPt);
     sp->addParam("FORMAT",getString("FORMAT",line));
     sensor->addMeter(sp);
@@ -1354,7 +1354,6 @@ void karamba::mouseReleaseEvent( QMouseEvent *e )
 {
   //qDebug("karamba::mouseReleaseEvent");
   clickPos = e->pos();
-  step();
 }
 
 void karamba::mouseDoubleClickEvent( QMouseEvent *e )
@@ -1610,8 +1609,7 @@ void karamba::widgetClosed()
 void karamba::slotToggleLocked()
 {
   //qDebug("karamba::slotToggleLocked");
-  bool locked = toggleLocked->isChecked();
-  if( toggleLocked -> isChecked() )
+  if(toggleLocked->isChecked())
   {
     toggleLocked->setIconSet(SmallIconSet("lock"));
   }
@@ -1735,7 +1733,7 @@ void karamba::passMenuItemClicked(int id)
   if (pythonIface && pythonIface->isExtensionLoaded())
   {
     KPopupMenu* menu = 0;
-    for(int i = 0; i < menuList->count(); i++)
+    for(int i = 0; i < (int)menuList->count(); i++)
     {
       KPopupMenu* tmp;
       if(i==0)
@@ -1799,7 +1797,7 @@ void karamba::startupRemoved(Startup* t)
     pythonIface->startupRemoved(this, t);
 }
 
-void  karamba::processExited (KProcess *proc)
+void  karamba::processExited (KProcess*)
 {
   //qDebug("karamba::processExited");
   // Nothing needed here at the moment.
@@ -1807,7 +1805,7 @@ void  karamba::processExited (KProcess *proc)
   // needed at some point.
 }
 
-void  karamba::receivedStdout (KProcess *proc, char *buffer, int buflen)
+void  karamba::receivedStdout (KProcess *proc, char *buffer, int)
 {
   //qDebug("karamba::receivedStdout");
   //Everything below is to call the python callback function
