@@ -24,7 +24,7 @@
 static const char *description =
     I18N_NOOP("A KDE Eye-candy Application");
 
-static const char *version = "0.35";
+static const char *version = "0.36";
 
 static KCmdLineOptions options[] =
 {
@@ -81,7 +81,7 @@ int main(int argc, char **argv)
     KCmdLineArgs::init(argc, argv, &about);
     KCmdLineArgs::addCmdLineOptions( options );
     KSessionManaged ksm;
-    karamba *mainWin = 0;
+    //karamba *mainWin = 0;
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
     QStringList lst;
     int ret = 0;
@@ -102,7 +102,7 @@ int main(int argc, char **argv)
     {
       //Set up systray icon
       //if(args->isSet("systray"))
-        app.setUpSysTray();
+      app.setUpSysTray();
       app.initDcopStub();
     }
 
@@ -128,7 +128,7 @@ int main(int argc, char **argv)
 
     KarambaPython::initPython();
     //qDebug("startThemes");
-    if (app.startThemes(app, lst))
+    if (app.startThemes(lst))
       ret = app.exec();
     KarambaPython::shutdownPython();
     return ret;
