@@ -64,13 +64,17 @@ MemSensor::MemSensor(int msec) : Sensor(msec)
 MemSensor::~MemSensor()
 {}
 
+#ifdef __FreeBSD__
 void MemSensor::receivedStdout(KProcess *, char *buffer, int len )
 {
-#ifdef __FreeBSD__
     buffer[len] = 0;
     sensorResult += QString( QCString(buffer) );
-#endif
 }
+#else
+void MemSensor::receivedStdout(KProcess *, char *, int)
+{
+}
+#endif
 
 void MemSensor::processExited(KProcess *)
 {
@@ -246,7 +250,7 @@ void MemSensor::update()
            setMaxValue(sp);
            bool set = true;
         }
-#endif 
+#endif
         meter = sp->getMeter();
         format = sp->getParam("FORMAT");
         if (format.length() == 0 )
