@@ -48,7 +48,7 @@ public:
   virtual void setValue(int) {};
   virtual int getValue() { return -1; };
   virtual void setValue(QString) {};
-  virtual QString getStringValue() { return QString::null; };
+  virtual QString getStringValue() const { return QString::null; };
   virtual void recalculateValue() {};
 
   virtual void setColor(int r, int g, int b) { color.setRgb(r, g, b); };
