@@ -8,30 +8,27 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#include <Python.h>
 #include <krun.h>
-
 #include "karamba.h"
-
 #include "richtextlabel.h"
 
 RichTextLabel::RichTextLabel(karamba* k) :
     Meter(0,0,100,100),
-    mykaramba(k),
     text(0),
-    underlineLinks(false),
     source(""),
-    colorGrp(k->colorGroup())
+    colorGrp(k->colorGroup()),
+    underlineLinks(false),
+    mykaramba(k)
 {
 }
 
 RichTextLabel::RichTextLabel(karamba* k, int x,int y,int w,int h) :
     Meter(x,y,w,h),
-    mykaramba(k),
     text(0),
-    underlineLinks(false),
     source(""),
-    colorGrp(k->colorGroup())
+    colorGrp(k->colorGroup()),
+    underlineLinks(false),
+    mykaramba(k)
 {
 }
 
@@ -145,8 +142,8 @@ void RichTextLabel::mUpdate(QPainter *p)
 
     int x = getX();
     int y = getY();
-    int width = getWidth();
-    int height = getHeight();
+    //int width = getWidth();
+    //int height = getHeight();
     QRect clipRect(0, 0, 0, 0); // no clipping
     text -> draw(p, x, y, clipRect, colorGrp, 0 /* no background */);
 }
