@@ -54,7 +54,7 @@ TaskManager::TaskManager(QObject *parent, const char *name)
 
     kwin_module = new KWinModule();
     kdDebug(155001) << "TaskManager::TaskManager()" << endl;
-	
+
 //    KGlobal::locale()->insertCatalogue("libtaskmanager");
     connect(kwin_module, SIGNAL(windowAdded(WId)), SLOT(windowAdded(WId)));
     connect(kwin_module, SIGNAL(windowRemoved(WId)), SLOT(windowRemoved(WId)));
@@ -65,7 +65,7 @@ TaskManager::TaskManager(QObject *parent, const char *name)
     // register existing windows
     const QValueList<WId> windows = kwin_module->windows();
     for (QValueList<WId>::ConstIterator it = windows.begin(); it != windows.end(); ++it )
-	windowAdded(*it);
+  windowAdded(*it);
 
     // set active window
     WId win = kwin_module->activeWindow();
@@ -106,53 +106,61 @@ Task* TaskManager::findTask(WId w)
     return 0;
 }
 
+#ifdef KDE_3_3
+#define NET_ALL_TYPES_MASK (NET::AllTypesMask)
+#else
+#define NET_ALL_TYPES_MASK (-1LU)
+#endif
+
 void TaskManager::windowAdded(WId w )
 {
-    NETWinInfo info (qt_xdisplay(),  w, qt_xrootwin(),
-		     NET::WMWindowType | NET::WMPid | NET::WMState );
+  NETWinInfo info(qt_xdisplay(),  w, qt_xrootwin(),
+                  NET::WMWindowType | NET::WMPid | NET::WMState );
+  #ifdef KDE_3_2
+  NET::WindowType windowType = info.windowType(NET_ALL_TYPES_MASK);
+  #else
+  NET::WindowType windowType = info.windowType();
+  #endif
+  // ignore NET::Tool and other special window types
+  if (windowType != NET::Normal && windowType != NET::Override
+      && windowType != NET::Unknown && windowType != NET::Dialog)
+    return;
+  // ignore windows that want to be ignored by the taskbar
+  if ((info.state() & NET::SkipTaskbar) != 0)
+  {
+      _skiptaskbar_windows.push_front( w ); // remember them though
+    return;
+  }
 
-    // ignore NET::Tool and other special window types
-    if (info.windowType() != NET::Normal
-        && info.windowType() != NET::Override
-        && info.windowType() != NET::Unknown
-        && info.windowType() != NET::Dialog)
-	return;
+  Window transient_for_tmp;
+  if (XGetTransientForHint(qt_xdisplay(), (Window) w, &transient_for_tmp))
+  {
+    WId transient_for = (WId) transient_for_tmp;
 
-    // ignore windows that want to be ignored by the taskbar
-    if ((info.state() & NET::SkipTaskbar) != 0) {
-        _skiptaskbar_windows.push_front( w ); // remember them though
-	return;
+    // check if it's transient for a skiptaskbar window
+    if (_skiptaskbar_windows.contains(transient_for))
+      return;
+
+    // lets see if this is a transient for an existing task
+    if (transient_for != qt_xrootwin() && transient_for != 0 )
+    {
+      Task* t = findTask(transient_for);
+      if (t)
+      {
+        if (t->window() != w)
+        {
+          t->addTransient(w);
+          // kdDebug() << "TM: Transient " << w << " added for Task: " << t->window() << endl;
+        }
+        return;
+      }
     }
+  }
+  Task* t = new Task(w, this);
+  _tasks.append(t);
 
-    Window transient_for_tmp;
-    if (XGetTransientForHint( qt_xdisplay(), (Window) w, &transient_for_tmp )) {
-        WId transient_for = (WId) transient_for_tmp;
-
-        // check if it's transient for a skiptaskbar window
-        if( _skiptaskbar_windows.contains( transient_for ))
-            return;
-    
-        // lets see if this is a transient for an existing task
-        if( transient_for != qt_xrootwin()
-            && transient_for != 0 ) {
-
-            Task* t = findTask(transient_for);
-            if (t) {
-	        if (t->window() != w) {
-		    t->addTransient(w);
-                    // kdDebug() << "TM: Transient " << w << " added for Task: " << t->window() << endl;
-                }
-	        return;
-            }
-	}
-    }
-
-    Task* t = new Task(w, this);
-    _tasks.append(t);
-
-    // kdDebug() << "TM: Task added for WId: " << w << endl;
-
-    emit taskAdded(t);
+  // kdDebug() << "TM: Task added for WId: " << w << endl;
+  emit taskAdded(t);
 }
 
 void TaskManager::windowRemoved(WId w )
@@ -306,40 +314,43 @@ bool TaskManager::isOnTop(const Task* task)
 
     for (QValueList<WId>::ConstIterator it = kwin_module->stackingOrder().fromLast();
          it != kwin_module->stackingOrder().end(); --it ) {
-	for (Task* t = _tasks.first(); t != 0; t = _tasks.next() ) {
-	    if ( (*it) == t->window() ) {
-		if ( t == task )
-		    return true;
-		if ( !t->isIconified() && (t->isAlwaysOnTop() == task->isAlwaysOnTop()) )
-		    return false;
-		break;
-	    }
-	}
+  for (Task* t = _tasks.first(); t != 0; t = _tasks.next() ) {
+      if ( (*it) == t->window() ) {
+    if ( t == task )
+        return true;
+    if ( !t->isIconified() && (t->isAlwaysOnTop() == task->isAlwaysOnTop()) )
+        return false;
+    break;
+      }
+  }
     }
     return false;
 }
 
 
-Task::Task(WId win, TaskManager * parent, const char *name)
-  : QObject(parent, name),
-    _active(false), _win(win),
-    _lastWidth(0), _lastHeight(0), _lastResize(false), _lastIcon(),
-    _thumbSize(0.2), _thumb(), _grab()
+Task::Task(WId win, TaskManager * parent, const char *name) :
+  QObject(parent, name),
+  _active(false), _win(win),
+  _lastWidth(0), _lastHeight(0), _lastResize(false), _lastIcon(),
+  _thumbSize(0.2), _thumb(), _grab()
 {
-    _info = KWin::info(_win);
+#ifdef KDE_3_2
+  _info = KWin::windowInfo(_win, 0, 0);
+#else
+  _info = KWin::info(_win);
+#endif
+  // try to load icon via net_wm
+  _pixmap = KWin::icon(_win, 16, 16, true);
 
-    // try to load icon via net_wm
-    _pixmap = KWin::icon(_win, 16, 16, true);
+  // try to guess the icon from the classhint
+  if(_pixmap.isNull())
+    KGlobal::instance()->iconLoader()->loadIcon(className().lower(),
+            KIcon::Small,KIcon::Small,
+            KIcon::DefaultState, 0, true);
 
-    // try to guess the icon from the classhint
-    if(_pixmap.isNull())
-      KGlobal::instance()->iconLoader()->loadIcon(className().lower(),
-						  KIcon::Small,KIcon::Small,
-						  KIcon::DefaultState, 0, true);
-
-    // load xapp icon
-    if (_pixmap.isNull())
-      _pixmap = SmallIcon("kcmx");
+  // load xapp icon
+  if (_pixmap.isNull())
+    _pixmap = SmallIcon("kcmx");
 }
 
 Task::~Task()
@@ -348,25 +359,31 @@ Task::~Task()
 
 void Task::refresh(bool icon)
 {
-    _info = KWin::info(_win);
-    if (icon) {
+#ifdef KDE_3_2
+  _info = KWin::windowInfo(_win, 0, 0);
+#else
+  _info = KWin::info(_win);
+#endif
+  if (icon)
+  {
+    // try to load icon via net_wm
+    _pixmap = KWin::icon(_win, 16, 16, true);
 
-        // try to load icon via net_wm
-        _pixmap = KWin::icon(_win, 16, 16, true);
-
-        // try to guess the icon from the classhint
-        if(_pixmap.isNull())
-            KGlobal::instance()->iconLoader()->loadIcon(className().lower(), KIcon::Small,
-                                                        KIcon::Small, KIcon::DefaultState, 0, true);
-
-        // load xapp icon
-        if (_pixmap.isNull())
-            _pixmap = SmallIcon("kcmx");
-
-	_lastIcon.resize(0,0);
-	emit iconChanged();
+    // try to guess the icon from the classhint
+    if(_pixmap.isNull())
+    {
+        KGlobal::instance()->iconLoader()->loadIcon(className().lower(),
+            KIcon::Small, KIcon::Small, KIcon::DefaultState, 0, true);
     }
-    emit changed();
+
+    // load xapp icon
+    if (_pixmap.isNull())
+      _pixmap = SmallIcon("kcmx");
+
+    _lastIcon.resize(0,0);
+    emit iconChanged();
+  }
+  emit changed();
 }
 
 void Task::setActive(bool a)
@@ -381,48 +398,76 @@ void Task::setActive(bool a)
 
 bool Task::isMaximized() const
 {
-    return(_info.state & NET::Max);
+#ifdef KDE_3_2
+  return(_info.state() & NET::Max);
+#else
+  return(_info.state & NET::Max);
+#endif
 }
 
 bool Task::isIconified() const
 {
-    return (_info.mappingState == NET::Iconic);
+#ifdef KDE_3_2
+  return (_info.mappingState() == NET::Iconic);
+#else
+  return (_info.mappingState == NET::Iconic);
+#endif
 }
 
 bool Task::isAlwaysOnTop() const
 {
-    return (_info.state & NET::StaysOnTop);
+#ifdef KDE_3_2
+  return (_info.state() & NET::StaysOnTop);
+#else
+  return (_info.state & NET::StaysOnTop);
+#endif
 }
 
 bool Task::isShaded() const
 {
-    return (_info.state & NET::Shaded);
+#ifdef KDE_3_2
+  return (_info.state() & NET::Shaded);
+#else
+  return (_info.state & NET::Shaded);
+#endif
 }
 
 bool Task::isOnCurrentDesktop() const
 {
-    return (_info.onAllDesktops || _info.desktop == kwin_module->currentDesktop());
+#ifdef KDE_3_2
+  return (_info.onAllDesktops() || _info.desktop() == kwin_module->currentDesktop());
+#else
+  return (_info.onAllDesktops || _info.desktop == kwin_module->currentDesktop());
+#endif
 }
 
 bool Task::isOnAllDesktops() const
 {
-    return _info.onAllDesktops;
+#ifdef KDE_3_2
+  return _info.onAllDesktops();
+#else
+  return _info.onAllDesktops;
+#endif
 }
 
 bool Task::isActive() const
 {
-    return _active;
+  return _active;
 }
 
 bool Task::isOnTop() const
 {
-    return taskManager()->isOnTop( this );
+  return taskManager()->isOnTop( this );
 }
 
 bool Task::isModified() const
 {
   static QString modStr = QString::fromUtf8("[") + i18n("modified") + QString::fromUtf8("]");
+#ifdef KDE_3_2
+  int modStrPos = _info.visibleName().find(modStr);
+#else
   int modStrPos = _info.visibleName.find(modStr);
+#endif
 
   return ( modStrPos != -1 );
 }
@@ -442,10 +487,10 @@ QString Task::className()
 {
     XClassHint hint;
     if(XGetClassHint(qt_xdisplay(), _win, &hint)) {
-	QString nh( hint.res_name );
-	XFree( hint.res_name );
-	XFree( hint.res_class );
-	return nh;
+  QString nh( hint.res_name );
+  XFree( hint.res_name );
+  XFree( hint.res_class );
+  return nh;
     }
     return QString::null;
 }
@@ -454,10 +499,10 @@ QString Task::classClass()
 {
     XClassHint hint;
     if(XGetClassHint(qt_xdisplay(), _win, &hint)) {
-	QString ch( hint.res_class );
-	XFree( hint.res_name );
-	XFree( hint.res_class );
-	return ch;
+  QString ch( hint.res_class );
+  XFree( hint.res_name );
+  XFree( hint.res_class );
+  return ch;
     }
     return QString::null;
 }
@@ -493,10 +538,10 @@ QPixmap Task::bestIcon( int size, bool &isStaticIcon )
 
       // Icon of last resort
       if( pixmap.isNull() ) {
-	pixmap = KGlobal::iconLoader()->loadIcon( "go",
-						  KIcon::NoGroup,
-						  KIcon::SizeSmall );
-	isStaticIcon = true;
+  pixmap = KGlobal::iconLoader()->loadIcon( "go",
+              KIcon::NoGroup,
+              KIcon::SizeSmall );
+  isStaticIcon = true;
       }
     }
     break;
@@ -509,17 +554,17 @@ QPixmap Task::bestIcon( int size, bool &isStaticIcon )
       pixmap = icon( 34, 34, false  );
 
       if ( ( pixmap.width() != 34 ) || ( pixmap.height() != 34 ) ) {
-	if ( ( pixmap.width() != 32 ) || ( pixmap.height() != 32 ) ) {
-	  pixmap = icon( 32, 32, true  );
-	}
+  if ( ( pixmap.width() != 32 ) || ( pixmap.height() != 32 ) ) {
+    pixmap = icon( 32, 32, true  );
+  }
       }
 
       // Icon of last resort
       if( pixmap.isNull() ) {
-	pixmap = KGlobal::iconLoader()->loadIcon( "go",
-						  KIcon::NoGroup,
-						  KIcon::SizeMedium );
-	isStaticIcon = true;
+  pixmap = KGlobal::iconLoader()->loadIcon( "go",
+              KIcon::NoGroup,
+              KIcon::SizeMedium );
+  isStaticIcon = true;
       }
     }
     break;
@@ -530,27 +575,27 @@ QPixmap Task::bestIcon( int size, bool &isStaticIcon )
 
       // If not, try to get one from the classname
       if ( pixmap.isNull() || pixmap.width() != size || pixmap.height() != size ) {
-	pixmap = KGlobal::iconLoader()->loadIcon( className(),
-						  KIcon::NoGroup,
-						  size,
-						  KIcon::DefaultState,
-						  0L,
-						  true );
-	isStaticIcon = true;
+  pixmap = KGlobal::iconLoader()->loadIcon( className(),
+              KIcon::NoGroup,
+              size,
+              KIcon::DefaultState,
+              0L,
+              true );
+  isStaticIcon = true;
       }
 
       // If we still don't have an icon then scale the one in the hints
       if ( pixmap.isNull() || ( pixmap.width() != size ) || ( pixmap.height() != size ) ) {
-	pixmap = icon( size, size, true  );
-	isStaticIcon = false;
+  pixmap = icon( size, size, true  );
+  isStaticIcon = false;
       }
 
       // Icon of last resort
       if( pixmap.isNull() ) {
-	pixmap = KGlobal::iconLoader()->loadIcon( "go",
-						  KIcon::NoGroup,
-						  size );
-	isStaticIcon = true;
+  pixmap = KGlobal::iconLoader()->loadIcon( "go",
+              KIcon::NoGroup,
+              size );
+  isStaticIcon = true;
       }
     }
   }
@@ -575,25 +620,32 @@ bool Task::idMatch( const QString& id1, const QString& id2 )
 
 void Task::maximize()
 {
-    NETWinInfo ni( qt_xdisplay(),  _win, qt_xrootwin(), NET::WMState);
-    ni.setState( NET::Max, NET::Max );
+  NETWinInfo ni( qt_xdisplay(),  _win, qt_xrootwin(), NET::WMState);
+  ni.setState( NET::Max, NET::Max );
 
-    if (_info.mappingState == NET::Iconic)
-        activate();
+#ifdef KDE_3_2
+  if (_info.mappingState() == NET::Iconic)
+#else
+  if (_info.mappingState == NET::Iconic)
+#endif
+    activate();
 }
 
 void Task::restore()
 {
-    NETWinInfo ni( qt_xdisplay(),  _win, qt_xrootwin(), NET::WMState);
-    ni.setState( 0, NET::Max );
-
-    if (_info.mappingState == NET::Iconic)
-        activate();
+  NETWinInfo ni( qt_xdisplay(),  _win, qt_xrootwin(), NET::WMState);
+  ni.setState( 0, NET::Max );
+#ifdef KDE_3_2
+  if (_info.mappingState() == NET::Iconic)
+#else
+  if (_info.mappingState == NET::Iconic)
+#endif
+    activate();
 }
 
 void Task::iconify()
 {
-    XIconifyWindow( qt_xdisplay(), _win, qt_xscreen() );
+  XIconifyWindow( qt_xdisplay(), _win, qt_xscreen() );
 }
 
 void Task::close()
@@ -634,19 +686,33 @@ void Task::activateRaiseOrIconify()
 
 void Task::toDesktop(int desk)
 {
-    NETWinInfo ni(qt_xdisplay(), _win, qt_xrootwin(), NET::WMDesktop);
-    if (desk == 0) {
-        if (_info.onAllDesktops) {
-            ni.setDesktop(kwin_module->currentDesktop());
-            KWin::setActiveWindow(_win);
-        }
-        else
-            ni.setDesktop(NETWinInfo::OnAllDesktops);
-        return;
+  NETWinInfo ni(qt_xdisplay(), _win, qt_xrootwin(), NET::WMDesktop);
+  if (desk == 0)
+  {
+#ifdef KDE_3_2
+    if (_info.onAllDesktops())
+    {
+        ni.setDesktop(kwin_module->currentDesktop());
+        KWin::forceActiveWindow(_win);
     }
-    ni.setDesktop(desk);
-    if(desk == kwin_module->currentDesktop())
+#else
+    if (_info.onAllDesktops)
+    {
+        ni.setDesktop(kwin_module->currentDesktop());
         KWin::setActiveWindow(_win);
+    }
+#endif
+    else
+        ni.setDesktop(NETWinInfo::OnAllDesktops);
+    return;
+  }
+  ni.setDesktop(desk);
+  if (desk == kwin_module->currentDesktop())
+#ifdef KDE_3_2
+    KWin::forceActiveWindow(_win);
+#else
+    KWin::setActiveWindow(_win);
+#endif
 }
 
 void Task::toCurrentDesktop()
@@ -708,10 +774,14 @@ void Task::updateThumbnail()
    // on slower machines.
    //
   QWidget *rootWin = qApp->desktop();
+#ifdef KDE_3_2
+  QRect geom = _info.geometry();
+#else
   QRect geom = _info.geometry;
+#endif
    _grab = QPixmap::grabWindow( rootWin->winId(),
-				geom.x(), geom.y(),
-				geom.width(), geom.height() );
+        geom.x(), geom.y(),
+        geom.width(), geom.height() );
 
    if ( !_grab.isNull() )
      QTimer::singleShot( 200, this, SLOT( generateThumbnail() ) );
