@@ -34,7 +34,7 @@ public:
     void setTextProps( TextField* );
     void setValue( QString );
     void setValue( int );
-    QString getStringValue() const { return value.join("\n"); };
+    virtual QString getStringValue() const { return value.join("\n"); };
     void setFontSize( int );
     void setBGColor( int, int, int);
     void setFont( QString );
