@@ -21,7 +21,7 @@ void WelcomeForm::helpButton_clicked()
 
 void WelcomeForm::downloadButton_clicked()
 {
-  KRun::runURL( KURL( "http://netdragon.sourceforge.net/index.php?page=Themes" ), "text/html" );
+  KRun::runURL( KURL( "http://www.superkaramba.com/" ), "text/html" );
 }
 
 void WelcomeForm::openButton_clicked()
